# frozen_string_literal: true

#--
# wwwjdic
# © 2014-2021 Marco Bresciani
#
# This file is part of wwwjdic.
#
# wwwjdic is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# wwwjdic is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with wwwjdic. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2014-2021 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative 'wwwjdic/application'
require_relative 'wwwjdic/parser'
require_relative 'wwwjdic/parsers/dict'
require_relative 'wwwjdic/parsers/display'
require_relative 'wwwjdic/parsers/key'
require_relative 'wwwjdic/parsers/search'
require_relative 'wwwjdic/parsers/server'

# Author:: {Marco Bresciani}[mailto:marcobresciani_1974@libero.it]
# Copyright:: © 2014-2021 Marco Bresciani
# License:: GNU General Public License version 3
module WWWJDic
  # Creates a new WWWJDic object (from the verb 'to Breen'... :) ).
  #
  # Usage::
  #   - <tt>new_wwwjdic = WWWJDic::breener</tt>
  # Returns:: a +WWWJDic+ object.
  def self.breener
    WWWJDic.new(parser)
  end

  # Provides the parameters' parsers object.
  def self.parser
    parsers = { dict: Parsers::Dict.new, display: Parsers::Display.new,
                key: Parsers::Key.new, search: Parsers::Search.new,
                server: Parsers::Server.new }

    Parser.new parsers
  end
end
